
Analysis
========

Documentation of studies undertaken in support of API and code design.

Feature Analysis
----------------

.. toctree::
   :titlesonly:

   features/header
   features/settings
   features/text/index
   features/table/index
   features/styles/index
   features/shapes/index
   features/coreprops
   features/numbering
   features/sections


Schema Analysis
---------------

Collected bits and pieces from the XML Schema docs, MSDN web pages, and the
ISO/IEC 29500 spec.

.. toctree::
   :maxdepth: 1

   schema/ct_document
   schema/ct_body
   schema/ct_p
